#include <u.h>
#include <libc.h>
#include <bio.h>
#include <ip.h>
#include <plumb.h>
#include <thread.h>
#include <fcall.h>
#include <9p.h>
#include <mp.h>
#include <libsec.h>
#include "dat.h"
#include "fns.h"


int
ioprint(Ioproc *io, int fd, char *fmt, ...)
{
	char buf[256];
	va_list args;
	int n;

	va_start(args, fmt);
	n = vsnprint(buf, sizeof(buf), fmt, args);
	va_end(args);
	if (n > 0)
		n = iowrite(io, fd, buf, n);
	return n;
}

static long
_iotlsdial(va_list *arg)
{
	char *addr, *local, *dir;
	int *cfdp, fd, tfd, usetls;
	TLSconn conn;

	addr = va_arg(*arg, char*);
	local = va_arg(*arg, char*);
	dir = va_arg(*arg, char*);
	cfdp = va_arg(*arg, int*);
	usetls = va_arg(*arg, int);

	fd = dial(addr, local, dir, cfdp);
	if(fd < 0)
		return -1;
	if(!usetls)
		return fd;

	memset(&conn, 0, sizeof conn);
	tfd = tlsClient(fd, &conn);
	if(tfd < 0){
		print("tls %r\n");
		close(fd);
		return -1;
	}
	/* BUG: check cert here? */
	if(conn.cert)
		free(conn.cert);
	close(fd);
	return tfd;
}

int
iotlsdial(Ioproc *io, char *addr, char *local, char *dir, int *cfdp, int usetls)
{
	return iocall(io, _iotlsdial, addr, local, dir, cfdp, usetls);
}
